==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/config_wizard/translations/config_wizard_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>言語設定を適用するにKaduを再起動する必要があります。</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;アカウントの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>ネットワークサービス</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>既存のアカウントを設定する</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>新規アカウントを作成する</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>今はアカウントを設定しない</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;利用したいアカウントのネットワークサービスを選択してください。&lt;/p&gt;&lt;p&gt;アカウントを持っていない場合はウィザードを使用してアカウントを作成することができます。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;設定が完了しました&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>このウィンドウを閉じた後にアカウント設定ウィンドウを開く</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Kaduを使用するために設定を完了してください。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>設定ウィザード</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Kaduインスタントメッセンジャーへようこそ&lt;/h3&gt;&lt;p&gt;このウィザードはKaduを設定するのに役立ちます。&lt;/p&gt;&lt;p&gt;まずは言語をニックネームを設定してください。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;プロファイルの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>ニックネーム</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;アカウントの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;アカウントの情報を入力してください。&lt;/p&gt;&lt;p&gt;他のアカウントを設定する場合は戻るボタンを押してください&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kaduの設定</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/config_wizard/translations/config_wizard_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>言語設定を適用するにKaduを再起動する必要があります。</translation>
    </message>
</context>
<context>
    <name>ConfigWizardActions</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;アカウントの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>ネットワークサービス</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>既存のアカウントを設定する</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>新規アカウントを作成する</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>今はアカウントを設定しない</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;利用したいアカウントのネットワークサービスを選択してください。&lt;/p&gt;&lt;p&gt;アカウントを持っていない場合はウィザードを使用してアカウントを作成することができます。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;設定が完了しました&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>このウィンドウを閉じた後にアカウント設定ウィンドウを開く</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Kaduを使用するために設定を完了してください。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Kaduインスタントメッセンジャーへようこそ&lt;/h3&gt;&lt;p&gt;このウィザードはKaduを設定するのに役立ちます。&lt;/p&gt;&lt;p&gt;まずは言語をニックネームを設定してください。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;プロファイルの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>ニックネーム</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;アカウントの設定&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;アカウントの情報を入力してください。&lt;/p&gt;&lt;p&gt;他のアカウントを設定する場合は戻るボタンを押してください&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kaduの設定</translation>
    </message>
</context>
</TS>
